# Particle-related classes

```eval_rst
.. currentmodule:: baggianalysis.core

.. autosummary::
    :nosignatures:

    Particle
    ParticleBond
    ParticleAngle
    ParticleDihedral
    ParticleSet
    System
    
.. autoclass:: Particle

.. autoclass:: ParticleBond

.. autoclass:: ParticleAngle

.. autoclass:: ParticleDihedral
    
.. autoclass:: ParticleSet
    
.. autoclass:: System
```
